"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["monaco-editor"],{9125:(e,t,o)=>{o.r(t),o.d(t,{default:()=>h});var n=o(8264),r=o(2650),i=o.n(r),A=o(5920),u=o(7388);function a(e){return a="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},a(e)}function c(){return c=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var o=arguments[t];for(var n in o)Object.prototype.hasOwnProperty.call(o,n)&&(e[n]=o[n])}return e},c.apply(this,arguments)}function l(e,t){for(var o=0;o<t.length;o++){var n=t[o];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,n.key,n)}}function f(e,t){return f=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(e,t){return e.__proto__=t,e},f(e,t)}function s(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var o,n=v(e);if(t){var r=v(this).constructor;o=Reflect.construct(n,arguments,r)}else o=n.apply(this,arguments);return p(this,o)}}function p(e,t){if(t&&("object"===a(t)||"function"==typeof t))return t;if(void 0!==t)throw new TypeError("Derived constructors may only return object or undefined");return d(e)}function d(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function v(e){return v=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(e){return e.__proto__||Object.getPrototypeOf(e)},v(e)}function y(e,t,o){return t in e?Object.defineProperty(e,t,{value:o,enumerable:!0,configurable:!0,writable:!0}):e[t]=o,e}var b=function(e){!function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&f(e,t)}(a,e);var t,o,r,u=s(a);function a(e){var t,o,r;return function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,a),y(d(r=u.call(this,e)),"editor",void 0),y(d(r),"onBlur",(function(){var e,t,o;null===(e=(t=r.props).onBlur)||void 0===e||e.call(t,(null===(o=r.editor)||void 0===o?void 0:o.getValue())||"")})),y(d(r),"editorDidMount",(function(e,t){var o,n;r.editor=e,r.props.onSave&&e.addCommand(t.KeyMod.CtrlCmd|t.KeyCode.KeyS,(function(){var t,o;null===(t=(o=r.props).onSave)||void 0===t||t.call(o,e.getValue())})),null===(o=(n=r.props).editorDidMount)||void 0===o||o.call(n,e,t)})),null===(t=(o=r.props).initMonaco)||void 0===t||t.call(o,n),r}return t=a,(o=[{key:"render",value:function(){var e=c({},this.props,{theme:this.props.theme.isDark?"vs-dark":"vs-light",options:c({wordWrap:"on",lineNumbers:"off",minimap:{enabled:!1},folding:!1,lineDecorationsWidth:5,overviewRulerBorder:!1,scrollBeyondLastLine:!1},this.props.options)});return this.props.alwaysShowHelpText&&(e.overrideServices=c({},e.overrideServices,{storageService:{get:function(){},getBoolean:function(e){return"expandSuggestionDocs"===e},store:function(){},onWillSaveState:function(){},onDidChangeStorage:function(){}}})),i().createElement("div",{onBlur:this.onBlur},i().createElement(A.ZP,c({editorDidMount:this.editorDidMount},e)))}}])&&l(t.prototype,o),r&&l(t,r),Object.defineProperty(t,"prototype",{writable:!1}),a}(r.PureComponent);const h=(0,u.withTheme)(b)},4748:e=>{e.exports="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAADsMAAA7DAcdvqGQAAAAZdEVYdFNvZnR3YXJlAHBhaW50Lm5ldCA0LjAuMTZEaa/1AAAAHUlEQVQYV2PYvXu3JAi7uLiAMaYAjAGTQBPYLQkAa/0Zef3qRswAAAAASUVORK5CYII="},4768:e=>{e.exports="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAQAAAC1+jfqAAAAL0lEQVQoz2NgCD3x//9/BhBYBWdhgFVAiVW4JBFKGIa4AqD0//9D3pt4I4tAdAMAHTQ/j5Zom30AAAAASUVORK5CYII="},5555:e=>{e.exports="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAQAAADZc7J/AAAAz0lEQVRIx2NgYGBY/R8I/vx5eelX3n82IJ9FxGf6tksvf/8FiTMQAcAGQMDvSwu09abffY8QYSAScNk45G198eX//yev73/4///701eh//kZSARckrNBRvz//+8+6ZohwCzjGNjdgQxkAg7B9WADeBjIBqtJCbhRA0YNoIkBSNmaPEMoNmA0FkYNoFKhapJ6FGyAH3nauaSmPfwI0v/3OukVi0CIZ+F25KrtYcx/CTIy0e+rC7R1Z4KMICVTQQ14feVXIbR695u14+Ir4gwAAD49E54wc1kWAAAAAElFTkSuQmCC"}}]);
//# sourceMappingURL=monaco-editor.js.map